@@ -80,16 +80,20 @@ bool reload_acl_and_cache(THD *thd, unsigned long long options,
 
   DBUG_ASSERT(!thd || !thd->in_sub_stmt);
 
+#ifndef NO_EMBEDDED_ACCESS_CHECKS
   if (options & REFRESH_GRANT)
   {
-#ifndef NO_EMBEDDED_ACCESS_CHECKS
     THD *tmp_thd= 0;
     /*
       If reload_acl_and_cache() is called from SIGHUP handler we have to
       allocate temporary THD for execution of acl_reload()/grant_reload().
     */
     if (unlikely(!thd) && (thd= (tmp_thd= new THD(0))))
+    {
       thd->store_globals();
+      thd->set_query_inner((char*) STRING_WITH_LEN("intern:reload_acl"),
+                           default_charset_info);
+    }
 
     if (likely(thd))
     {
@@ -124,11 +128,8 @@ bool reload_acl_and_cache(THD *thd, unsigned long long options,
       thd= 0;
     }
     reset_mqh((LEX_USER *)NULL, TRUE);
-#else
-    if ((result= thd && servers_reload(thd)))
-      my_error(ER_UNKNOWN_ERROR, MYF(0));
-#endif
   }
+#endif
   if (options & REFRESH_LOG)
   {
     /*
@@ -378,7 +379,11 @@ bool reload_acl_and_cache(THD *thd, unsigned long long options,
   if (options & REFRESH_HOSTS)
     hostname_cache_refresh();
   if (thd && (options & REFRESH_STATUS))
-    refresh_status(thd);
+    refresh_status_legacy(thd);
+  if (thd && (options & REFRESH_SESSION_STATUS))
+    refresh_session_status(thd);
+  if ((options & REFRESH_GLOBAL_STATUS))
+    refresh_global_status();
   if (options & REFRESH_THREADS)
     thread_cache.flush();
 #ifdef HAVE_REPLICATION
@@ -621,7 +626,7 @@ bool flush_tables_with_read_lock(THD *thd, TABLE_LIST *all_tables)
       if (table_list->belong_to_view &&
           check_single_table_access(thd, PRIV_LOCK_TABLES, table_list, FALSE))
       {
-        table_list->replace_view_error_with_generic(thd);
+        table_list->hide_view_error(thd);
         goto error_reset_bits;
       }
       if (table_list->is_view_or_derived())
